@@ -2,10 +2,13 @@ import logging
 from abc import ABC, abstractmethod
 from typing import List
 
+from django.conf import settings
 from django.db import connections
 from django.db.backends.base.base import BaseDatabaseWrapper
 from django.db.utils import OperationalError
 
+from wise.utils.redis import get_redis_client
+
 logger = logging.getLogger(__name__)
 
 
@@ -41,6 +44,26 @@ class KafkaCheck(BaseCheck):
         return True
 
 
+class RedisCheck(BaseCheck):
+    def __init__(self):
+        super(RedisCheck, self).__init__()
+
+    def check(self) -> bool:
+        if (
+            hasattr(settings, "ENV")
+            and hasattr(settings.ENV, "redis")
+            and getattr(settings.ENV.redis, "enabled", True)
+        ):
+            try:
+                get_redis_client().ping()
+                return True
+            except ConnectionError as ce:
+                logger.error(f"Redis Check error: {ce}")
+                return False
+        else:
+            return True
+
+
 class HealthCheck:
     def __init__(self) -> None:
         self._checks: List[BaseCheck] = []
@@ -58,3 +81,4 @@ class HealthCheck:
 health_check = HealthCheck()
 health_check.add(DBCheck())
 health_check.add(KafkaCheck())
+health_check.add(RedisCheck())
