@@ -6,6 +6,7 @@ class EnvSettings(BaseSettings):
     debug: bool
     secret_key: StrictStr
     service_name: StrictStr
+    environment: str | None = None
 
     model_config = SettingsConfigDict(
         env_prefix="",
@@ -30,6 +31,8 @@ class KafkaSettings(BaseModel):
     username: StrictStr
     password: StrictStr
     group_id: StrictStr
+    max_poll_records: int = 500
+    max_poll_interval_ms: int = 300000
 
 
 class PostgresSettings(BaseModel):
