@@ -10,14 +10,19 @@ from opentelemetry.sdk.trace.export import (
     BatchSpanProcessor,
 )
 
+tracing_settings = getattr(settings.ENV, "tracing", None)
+
 resource = Resource(
     attributes={
-        SERVICE_NAME: settings.ENV.tracing.service_name or settings.ENV.service_name
+        SERVICE_NAME: getattr(tracing_settings, "service_name", None)
+        or settings.ENV.service_name
     }
 )
 provider = TracerProvider(resource=resource)
-processor = BatchSpanProcessor(OTLPSpanExporter(endpoint=settings.ENV.tracing.url))
-if settings.ENV.tracing.enabled:
+if getattr(tracing_settings, "enabled", False):
+    processor = BatchSpanProcessor(
+        OTLPSpanExporter(endpoint=getattr(tracing_settings, "url"))
+    )
     provider.add_span_processor(processor)
 
 trace.set_tracer_provider(provider)
